@@ -5,14 +5,19 @@ try:
 except ImportError:
     async_to_sync = None
 
+from django.contrib.sessions.backends.file import SessionStore
 from django.core.exceptions import ImproperlyConfigured
 from django.test import RequestFactory, TestCase, override_settings
-from requests import Request
 
 from log_request_id import DEFAULT_NO_REQUEST_ID, local
-from log_request_id.session import Session
 from log_request_id.middleware import RequestIDMiddleware
 from testproject.views import test_view, test_async_view
+from unittest import mock
+
+
+class DummyUser(object):
+    pk = 'fake_pk'
+    username = 'fake_username'
 
 
 class RequestIDLoggingTestCase(TestCase):
@@ -32,9 +37,15 @@ class RequestIDLoggingTestCase(TestCase):
         except AttributeError:
             pass
 
+    @mock.patch("log_request_id.middleware.RequestIDMiddleware._generate_id")
+    def test_request(self, mock_generate_id):
+        mock_generate_id.return_value = "test_id"
+        self.client.get(self.url)
+        self.assertTrue("test_id" in self.handler.messages[0])
+
     def test_id_generation(self):
         request = self.factory.get(self.url)
-        middleware = RequestIDMiddleware()
+        middleware = RequestIDMiddleware(get_response=lambda request: None)
         middleware.process_request(request)
         self.assertTrue(hasattr(request, 'id'))
         self.call_view(request)
@@ -44,7 +55,7 @@ class RequestIDLoggingTestCase(TestCase):
         with self.settings(LOG_REQUEST_ID_HEADER='REQUEST_ID_HEADER'):
             request = self.factory.get(self.url)
             request.META['REQUEST_ID_HEADER'] = 'some_request_id'
-            middleware = RequestIDMiddleware()
+            middleware = RequestIDMiddleware(get_response=lambda request: None)
             middleware.process_request(request)
             self.assertEqual(request.id, 'some_request_id')
             self.call_view(request)
@@ -64,7 +75,7 @@ class RequestIDLoggingTestCase(TestCase):
     def test_external_id_missing_in_http_header_should_fallback_to_generated_id(self):
         with self.settings(LOG_REQUEST_ID_HEADER='REQUEST_ID_HEADER', GENERATE_REQUEST_ID_IF_NOT_IN_HEADER=True):
             request = self.factory.get(self.url)
-            middleware = RequestIDMiddleware()
+            middleware = RequestIDMiddleware(get_response=lambda request: None)
             middleware.process_request(request)
             self.assertTrue(hasattr(request, 'id'))
             self.call_view(request)
@@ -78,7 +89,7 @@ class RequestIDLoggingTestCase(TestCase):
         with self.settings(LOG_REQUESTS=True):
             request = self.factory.get(self.url)
             request.user = DummyUser()
-            middleware = RequestIDMiddleware()
+            middleware = RequestIDMiddleware(get_response=lambda request: None)
             middleware.process_request(request)
             response = self.call_view(request)
             middleware.process_response(request, response)
@@ -86,26 +97,47 @@ class RequestIDLoggingTestCase(TestCase):
             self.assertTrue('fake_pk' in self.handler.messages[1])
 
     def test_log_user_attribute(self):
-
-        class DummyUser(object):
-            pk = 'fake_pk'
-            username = 'fake_username'
-
         with self.settings(LOG_REQUESTS=True, LOG_USER_ATTRIBUTE='username'):
             request = self.factory.get(self.url)
             request.user = DummyUser()
-            middleware = RequestIDMiddleware()
+            request.session = SessionStore("session_key")
+            middleware = RequestIDMiddleware(get_response=lambda request: None)
             middleware.process_request(request)
             response = self.call_view(request)
             middleware.process_response(request, response)
             self.assertEqual(len(self.handler.messages), 2)
             self.assertTrue('fake_username' in self.handler.messages[1])
 
+    def test_log_user_attribute_anonymous_user(self):
+        with self.settings(LOG_REQUESTS=True, LOG_USER_ATTRIBUTE='username'):
+            request = self.factory.get(self.url)
+            request.session = SessionStore()
+            middleware = RequestIDMiddleware(get_response=lambda request: None)
+            middleware.process_request(request)
+            response = self.call_view(request)
+            middleware.process_response(request, response)
+            self.assertEqual(len(self.handler.messages), 2)
+            self.assertFalse('fake_username' in self.handler.messages[1])
+            self.assertFalse(request.session.accessed)
+
+    def test_log_user_attribute_unset(self):
+        with self.settings(LOG_REQUESTS=True, LOG_USER_ATTRIBUTE=None):
+            request = self.factory.get(self.url)
+            request.user = DummyUser()
+            request.session = SessionStore("session_key")
+            middleware = RequestIDMiddleware(get_response=lambda request: None)
+            middleware.process_request(request)
+            response = self.call_view(request)
+            middleware.process_response(request, response)
+            self.assertEqual(len(self.handler.messages), 2)
+            self.assertFalse('fake_username' in self.handler.messages[1])
+            self.assertFalse(request.session.accessed)
+
     def test_response_header_unset(self):
         with self.settings(LOG_REQUEST_ID_HEADER='REQUEST_ID_HEADER'):
             request = self.factory.get(self.url)
             request.META['REQUEST_ID_HEADER'] = 'some_request_id'
-            middleware = RequestIDMiddleware()
+            middleware = RequestIDMiddleware(get_response=lambda request: None)
             middleware.process_request(request)
             response = self.call_view(request)
             self.assertFalse(response.has_header('REQUEST_ID'))
@@ -114,55 +146,13 @@ class RequestIDLoggingTestCase(TestCase):
         with self.settings(LOG_REQUEST_ID_HEADER='REQUEST_ID_HEADER', REQUEST_ID_RESPONSE_HEADER='REQUEST_ID'):
             request = self.factory.get(self.url)
             request.META['REQUEST_ID_HEADER'] = 'some_request_id'
-            middleware = RequestIDMiddleware()
+            middleware = RequestIDMiddleware(get_response=lambda request: None)
             middleware.process_request(request)
             response = self.call_view(request)
             middleware.process_response(request, response)
             self.assertTrue(response.has_header('REQUEST_ID'))
 
 
-class RequestIDPassthroughTestCase(TestCase):
-    url = "/"
-
-    def setUp(self):
-        self.factory = RequestFactory()
-
-    def test_request_id_passthrough_with_custom_header(self):
-        with self.settings(LOG_REQUEST_ID_HEADER='REQUEST_ID_HEADER', OUTGOING_REQUEST_ID_HEADER='OUTGOING_REQUEST_ID_HEADER'):
-            request = self.factory.get(self.url)
-            request.META['REQUEST_ID_HEADER'] = 'some_request_id'
-            middleware = RequestIDMiddleware()
-            middleware.process_request(request)
-            self.assertEqual(request.id, 'some_request_id')
-            session = Session()
-            outgoing = Request('get', 'http://nowhere')
-            session.prepare_request(outgoing)
-            self.assertEqual(
-                outgoing.headers['OUTGOING_REQUEST_ID_HEADER'],
-                'some_request_id'
-            )
-
-    def test_request_id_passthrough(self):
-        with self.settings(LOG_REQUEST_ID_HEADER='REQUEST_ID_HEADER'):
-            request = self.factory.get(self.url)
-            request.META['REQUEST_ID_HEADER'] = 'some_request_id'
-            middleware = RequestIDMiddleware()
-            middleware.process_request(request)
-            self.assertEqual(request.id, 'some_request_id')
-            session = Session()
-            outgoing = Request('get', 'http://nowhere')
-            session.prepare_request(outgoing)
-            self.assertEqual(
-                outgoing.headers['REQUEST_ID_HEADER'],
-                'some_request_id'
-            )
-
-    def test_misconfigured_for_sessions(self):
-        def inner():
-            Session()
-        self.assertRaises(ImproperlyConfigured, inner)
-
-
 # asgiref is required from Django 3.0
 if async_to_sync:
 
@@ -171,7 +161,3 @@ if async_to_sync:
 
         def call_view(self, request):
             return async_to_sync(test_async_view)(request)
-
-
-    class AsyncRequestIDPassthroughTestCase(RequestIDPassthroughTestCase):
-        url = "/async/"
